<?php
declare(strict_types=1);

namespace Inti\Wp\Container;

use JsonException;
use Psr\Container\ContainerInterface;
use function file_exists;
use function file_get_contents;
use function json_decode;
use function realpath;

/**
 * Class AssetManifestFactory
 *
 * @package Inti\Wp\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class AssetManifestFactory
{
    /**
     * @param ContainerInterface $container
     * @return array
     * @throws JsonException
     */
    public function __invoke(ContainerInterface $container): array
    {
        $config = $container->has('config') ? $container->get('config') : [];
        $manifestPath = realpath($config['wp']['assets']['manifest_path']);

        if (!$manifestPath || !file_exists($manifestPath)) {
            return [];
        }

        $manifest = file_get_contents($manifestPath);
        return json_decode($manifest, true, 512, JSON_THROW_ON_ERROR);
    }
}
